#!/bin/sh
# $Id: configure.sh,v 1.9 2005/07/11 22:37:57 jimb Exp $
# Author   : Jim Brooks http://www.jimbrooks.org
# Synopsis : Simple configuration script.
#            Mainly intended for configuration on Linux or FreeBSD.
# Notes    : gtk[glib]-config is named gtk12[glib12]-config on FreeBSD 4.4.
# --------------------------------------------------------------------------

# Returns PROG if it exists in PATH.
CheckGtkProg()
{
    PROG1=$1
    PROG2=$2
    ERROR=$3

    if ( $PROG1 --version >/dev/null 2>/dev/null ); then
        PROG=$PROG1
        echo "Found $PROG (ok)."
        return
    fi

    if ( $PROG2 --version >/dev/null 2>/dev/null ); then
        PROG=$PROG2
        echo "Found $PROG (ok)."
        return
    fi

    echo "$ERROR"
    echo " "
    echo "GTK+ 1.2.x usually isn't installed by modern Linux/BSD distributions ;-("
    echo " "
    echo "For example, on Fedora 3, you'll need to install these packages: "
    echo "glib-devel-1.2.10-15.i386.rpm"
    echo "gtk+-devel-1.2.10-33.i386.rpm"
    echo "gnome-libs-1.4.1.2.90-44.i386.rpm"
    echo "gnome-libs-devel-1.4.1.2.90-44.i386.rpm"
    echo "compat-db-4.1.25-6.i386.rpm"
    echo "imlib-devel-1.9.13-21.i386.rpm"
    echo "libIDL-devel-0.8.4-1.i386.rpm"
    echo "ORBit-0.5.17-14.i386.rpm"
    echo "ORBit-devel-0.5.17-14.i386.rpm"

    exit 1
}

echo "Checking for required GTK+ 1.2.x libs and development packages..."

# gtk-config or gtk12-config?
# First look for gtk12-config (in case gtk-config is for > GTK+ 1.2.x).
CheckGtkProg glib12-config glib-config "ERROR: glib-config not found, requires glib-devel (GTK+ 1.2.x) package."
GLIB_CONFIG=$PROG

CheckGtkProg gtk12-config gtk-config "ERROR: gtk-config not found, requires gtk-devel (GTK+ 1.2.x) package."
GTK_CONFIG=$PROG

CheckGtkProg gnome-config gnome-config "ERROR: gnome-config not found, requires gnome-config (GTK+ 1.2.x) package."
GNOME_CONFIG=$PROG

# Create config file to be included by GNUmakefile.
echo "#--- AUTO-GENERATED by configure.sh on `uname` ---"  > GNUmakefile.config
echo "GTK_CONFIG=${GTK_CONFIG}"                           >> GNUmakefile.config
echo "GLIB_CONFIG=${GLIB_CONFIG}"                         >> GNUmakefile.config
echo "GNOME_CONFIG=${GNOME_CONFIG}"                       >> GNUmakefile.config

# Depending on system, determine name of GNU make and create a "makefile".
if [ "`uname -a | grep Linux`" != "" ]
then
	# Linux.
	GMAKE=make
else
	# BSD or not Linux.
	GMAKE=gmake

	# Create a traditional "makefile" which defers to GNU make.
	echo "#--- AUTO-GENERATED by configure.sh on `uname` ---"  > makefile
	echo "all .DEFAULT:"                                      >> makefile
	# This echo starts with a TAB (echo -e doesn't work on Solaris).
	echo "	${GMAKE} -f GNUmakefile \$@"                      >> makefile
fi

# Ensure GNU make is installed.
if [ "`$GMAKE --version 2>/dev/null | grep GNU`" = "" ]
then
	echo "-- ERROR: GNU make is not installed."
	exit 1
fi

# Check if Exuberant ctags is installed, but if it isn't just warn.
FOUND_CTAGS=0
FindCtags()
{
    if [ "$FOUND_CTAGS" = "0" ]; then
        CTAGS=$1
        if ( which $CTAGS >/dev/null 2>&1 ); then
            FOUND_CTAGS=1
        elif ( $CTAGS --help 2>&1 | grep Exuberant >/dev/null ); then
            FOUND_CTAGS=1
        fi
    fi
}
FindCtags ctags
FindCtags exuberant-ctags
FindCtags exctags
if [ "$FOUND_CTAGS" = "0" ]; then
    echo "-- Warning:"
    echo "-- hypersrc depends on Exuberant ctags which doesn't appear to be installed"
    echo "-- (or GNU ctags precedes it in PATH?)"
	echo "-- Exuberant ctags is available at:"
	echo "-- http://ctags.sourceforge.net or ftp.jimbrooks.org/hypersrc/exuberant_ctags/"
fi

echo "Configured for `uname`."
echo "Now do:"
echo "make install"

exit 0
